import MenuChange from "@/components/MenuChange";
import { MyIcon } from "@/global";
import { ProColumns } from "@ant-design/pro-components";
import { useModel } from "@umijs/max";
import { Badge, Button, Space, Switch, TableColumnsType, Tag, Tooltip } from "antd";

export const columns = (props: { appType: any}): ProColumns<any>[] => {
    let { getEnum } = useModel("global")
    return [
        {
            title: "应用名称",
            dataIndex: 'appName',
            key: "appName",
            align: "center",
            render: (a: any, b: any) => {
                return <Space size={[3, 0]}>
                    <MyIcon type={props?.appType === 2 ? "icon-xiaochengxu-dy" : "icon-xiaochengxu-wx"} />
                    {b.appName}
                </Space>
            }
        },
        {
            title: "应用标识",
            dataIndex: 'appKey',
            key: "appKey",
            align: "center",
        },
        {
            title: "小程序类型",
            dataIndex: 'appCategory',
            key: "appCategory",
            align: "center",
            valueEnum: getEnum("APP_CATEGORY", 'map')
        },
        {
            title: "允许投放渠道",
            dataIndex: 'advertisingChannels',
            valueType:'select',
            key: "advertisingChannels",
            align: "center",
            valueEnum:getEnum("ADVERTISING_CHANNEL","map")
        },
        {
            title: "首页地址",
            dataIndex: 'homePage',
            key: "homePage",
            align: "center",
            hideInSearch: true,
        },
        {
            title: "应用版本",
            dataIndex: 'appVersion',
            key: "appVersion",
            align: "center",
            hideInSearch: true,
        },
        {
            title: '小程序配置信息（json）',
            dataIndex: 'configParamList',
            key: 'configParamList',
            align: 'center',
            hideInSearch: true,
            render: (a, b) => {
                return (
                    <Space size={[0, 0]} wrap>
                        {b?.configParamList?.map((item: any, index: number) => {
                            return (
                                <Tooltip title={JSON.stringify(item['additionalProp' + (index + 1)])} key={index}>
                                    <Button type="link" size="small">
                                        配置{index + 1}
                                    </Button>
                                </Tooltip>
                            );
                        })}
                    </Space>
                );
            },
        },
        {
            title: 'ios支付版本号',
            tooltip: "ios的特殊性,此版本号与IOS支付模块关联,小程序版本号<=此版本号IOS才会出现支付功能,(微信)小程序发布线上后必须设置",
            dataIndex: 'iosPayment',
            align: "center",
            hideInSearch: true,
            render: (_, d) => {
                return d.iosPayment ? <Tag color="processing" bordered={false}>{d.iosPayment}</Tag> : <Tag color="error" bordered={false}>IOS无法支付</Tag>
            }
        },
        {
            title: '小程序页面模板信息',
            dataIndex: 'templateName',
            key: 'templateName',
            align: "center",
            ellipsis: true,
            hideInSearch: true,
        },
        {
            title: '状态',
            dataIndex: 'enabled',
            key: 'enabled',
            align: 'center',
            ellipsis: true,
            hideInSearch: true,
            render: (a: any, b: any) => {
                return (
                    <Switch
                        checkedChildren="正常"
                        unCheckedChildren="停用"
                        checked={b?.enabled}
                        disabled
                    />
                );
            },
        },
        {
            title: "运营载体状态",
            dataIndex: 'appCarrierList',
            key: "appCarrierList",
            hideInSearch: true,
            align: "center",
            render: (a, b: any) => {
                let isTrue = b?.appCarrierList?.length > 0
                return <Badge status={isTrue ? "processing" : "error"} text={isTrue ? "有" : "无"} />
            }
        },
        {
            title: "操作",
            dataIndex: 'option',
            valueType: 'option',
            align: "center",
            render: (_, record) => {
                return <Space>
                    <MenuChange menuType="miniApp" data={{ ...record, appType: props.appType }}><a type='primary'>管理</a></MenuChange>
                </Space>
            },
        },
    ];
}
export const childrenColumns: TableColumnsType<any> = [
    {
        title: "载体名称",
        dataIndex: 'carrierName',
        key: "carrierName",
        align: "center",
    },
    {
        title: "载体类型",
        dataIndex: 'carrierType',
        key: "carrierType",
        align: "center",
        render: (a: string, b: any) => {
            return { '1': '企业微信', "2": "公众号" }[a]
        }
    },
    {
        title: "绑定时间",
        dataIndex: 'createTime',
        key: "createTime",
        align: "center",
    }
]